import{q as o,a as r,b as a,t as n,f as i,g as c,_ as p,h as _,j as h,T as u,P as d,C as l,M as m,s as g,i as t,k as v,l as w,m as f}from"./registerWidgets.fff064a1.js";const k={};function y(e,W){const s=r("router-view");return a(),n(s,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const b=o(k,[["render",y]]),x=i({history:c("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>p(()=>import("./Player.eb229b81.js"),["assets/Player.eb229b81.js","assets/index.314cf40a.js","assets/registerWidgets.fff064a1.js","assets/registerWidgets.c4c71ee6.css","assets/WidgetsFrame.7e48c68b.js","assets/CircularLoading.59d7fd3d.js","assets/CircularLoading.f81b57b4.css","assets/icons.b8ff2c28.js","assets/Modal.2ceba592.js","assets/Modal.29f9eb98.css","assets/WidgetsFrame.783acd39.css","assets/broker.b9a40809.js","assets/broker.b057aed3.css","assets/DashPlayer.d88d0731.js","assets/runnerData.81f4c073.js","assets/DashPlayer.f60035bd.css","assets/Player.82401ce5.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),A=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=_({render:()=>h(b)});u.init(),e.use(x),e.use(d),e.mount("#app"),e.component("VSelect",l),e.component("Markdown",m),e.component("Message",g),t(e,v),t(e,w),t(e,f)};A();
//# sourceMappingURL=player.821c820c.js.map
