import{d,r as y,G as N,b as s,c as n,A as B,v as r,H as b,z as A,y as x,q as p,F as k,J as S,K as E,L as F,E as $,e as i,I,B as v,t as C,w as D,N as L,O,a as P}from"./registerWidgets.fff064a1.js";import{d as R,s as z,w as V,a as W,b as H,c as J}from"./icons.b8ff2c28.js";const M={class:"text"},U=d({__name:"Tooltip",props:{text:{type:String,required:!0},left:{type:Number},top:{type:Number},fixed:{type:Boolean,default:!1}},setup(e){const a=e,_=y(Date.now()),c=()=>{_.value=Date.now()},u=y(null),h=()=>{var t,g,w;const o=(t=u.value)==null?void 0:t.getBoundingClientRect();if(!o)return{};const{x:m,y:l}=o;return _.value,{position:"fixed",top:`${l+((g=a.top)!=null?g:0)}px`,left:`${m+((w=a.left)!=null?w:0)}px`}},f=N(()=>{var o;return a.fixed?h():{left:`${(o=a.left)!=null?o:-14}px`,...a.top?{top:`${a.top}px`}:{}}});return(o,m)=>(s(),n("div",{ref_key:"tooltipBox",ref:u,class:"tooltip-box",onMouseenter:c},[B(o.$slots,"default",{},void 0,!0),r("div",{class:"tooltip",style:A(x(f))},[r("span",M,b(e.text),1)],4)],544))}});const j=p(U,[["__scopeId","data-v-74636348"]]),G={class:"sidebar"},K={class:"section-name"},Q=["onClick"],X={class:"item-name"},Y={key:0,class:"tag soon"},Z={key:1,class:"tag beta"},ee={key:2,class:"tag cloud"},te=d({__name:"Sidebar",setup(e){var f;const a=E(),_=F(),c=y((f=_.name)!=null?f:"forms"),u=N(()=>[{name:"Runtime",items:[{name:"Forms",icon:R,path:"forms"},{name:"Jobs",icon:z,path:"jobs",cloud:!0},{name:"Hooks",icon:V,path:"hooks"},{name:"Dashes",icon:W,path:"dashes",beta:!0}]},{name:"Settings",items:[{name:"Settings",icon:H,path:"settings"}]}]),h=o=>{o.unavailable||(a.push(o.path),c.value=o.path)};return(o,m)=>(s(),n("div",G,[(s(!0),n(k,null,S(x(u),l=>(s(),n("div",{key:l.name,class:"section"},[r("span",K,b(l.name),1),(s(!0),n(k,null,S(l.items,t=>(s(),n("div",{key:t.name,role:"button",class:$(["item",{active:c.value===t.path,disabled:t.unavailable||l.cloud}]),tabindex:"0",onClick:g=>h(t)},[i(I,{class:$(["icon",{disabled:t.unavailable,active:c.value===t.path}]),path:t.icon,width:"20",height:"20"},null,8,["class","path"]),r("span",X,b(t.name),1),t.unavailable?(s(),n("span",Y,"SOON")):v("",!0),t.beta?(s(),n("span",Z,"BETA")):v("",!0),t.cloud?(s(),n("span",ee,"CLOUD")):v("",!0),t.warning?(s(),C(j,{key:3,class:"warning",text:t.warning,fixed:!0,top:18,left:18},{default:D(()=>[i(I,{path:x(J),fill:"#D35249",width:"20",height:"20"},null,8,["path"])]),_:2},1032,["text"])):v("",!0)],10,Q))),128))]))),128))]))}});const se=p(te,[["__scopeId","data-v-641517f2"]]),ae="/assets/logo.0faadfa2.svg";const oe={},T=e=>(L("data-v-eafe8f3e"),e=e(),O(),e),ne={class:"logo"},ce=T(()=>r("img",{class:"logo",src:ae,alt:"Abstra cloud logo"},null,-1)),re=T(()=>r("span",null," Abstra ",-1)),_e=[ce,re];function le(e,a){return s(),n("div",ne,_e)}const ie=p(oe,[["render",le],["__scopeId","data-v-eafe8f3e"]]),pe=["href"],ue=d({__name:"PrimaryLink",props:{url:{type:String,required:!0},alternative:{type:Boolean,required:!1}},setup(e){return(a,_)=>(s(),n("a",{target:"_blank",href:e.url,class:$([{alternative:e.alternative}])},[B(a.$slots,"default",{},void 0,!0)],10,pe))}});const de=p(ue,[["__scopeId","data-v-eaebd10e"]]),q=e=>(L("data-v-308246f6"),e=e(),O(),e),he=q(()=>r("span",{class:"long"}," DOCUMENTATION ",-1)),fe=q(()=>r("span",{class:"short"}," DOCS ",-1)),ve=d({__name:"NavbarDocumentationLink",props:{page:{type:String,required:!1}},setup(e){var c;const _="https://docs.abstracloud.com/"+((c=e.page)!=null?c:"");return(u,h)=>(s(),C(de,{class:"button",url:_},{default:D(()=>[he,fe]),_:1}))}});const me=p(ve,[["__scopeId","data-v-308246f6"]]),ge={class:"workspace"},ye=d({__name:"Workspace",setup(e){return(a,_)=>{const c=P("router-view");return s(),n(k,null,[r("nav",null,[i(ie),i(me)]),r("div",ge,[i(se,{class:"sidebar"}),i(c,{class:"view"})])],64)}}});const ke=p(ye,[["__scopeId","data-v-69a3c5a5"]]);export{ke as default};
//# sourceMappingURL=Workspace.082a7639.js.map
