[data-v-a1632005]:root{--main-font-family: DM Sans, sans-serif}[data-v-a1632005]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #2479df}.terminal[data-v-a1632005]{width:100%;background:#272d35;padding:12px 20px;box-sizing:border-box;position:relative;display:flex;flex-direction:column;font-size:14px;font-weight:400;line-height:17px}.terminal .resize-handler[data-v-a1632005]{position:absolute;top:0;left:0;right:0;height:4px;transform:translateY(-50%);cursor:ns-resize;background:transparent}.terminal .resize-handler[data-v-a1632005]:hover,.terminal .resize-handler.resizing[data-v-a1632005]{background:#777}.terminal .cli[data-v-a1632005]{height:100%;width:100%;display:flex;flex-direction:row;font-family:Courier New,Courier,monospace}.terminal .cli .left[data-v-a1632005]{display:flex;flex-direction:column;height:100%;width:100%}.terminal .cli .left .entries[data-v-a1632005]{display:flex;flex-direction:column;flex-grow:1;overflow-y:scroll;color:#fff}.terminal .cli .left .entries[data-v-a1632005]::-webkit-scrollbar{display:none}.terminal .cli .left .entries .entry[data-v-a1632005]{padding:4px 8px}.terminal .cli .left .entries .entry.stderr[data-v-a1632005],.terminal .cli .left .entries .entry.stdout[data-v-a1632005]{font-family:monospace;white-space:pre-line}.terminal .cli .left .entries .entry.stderr[data-v-a1632005]{color:#f37971}.terminal .cli .left .entries .entry.stdout[data-v-a1632005]{color:#a5dbb7}.terminal .cli .left .entries .entry.ai-output[data-v-a1632005]{color:#e2f371}.terminal .cli .left .entries .local-entry[data-v-a1632005]{white-space:pre-line}.terminal .cli .left .entries .loading[data-v-a1632005]{align-self:center}.terminal .cli .left .input[data-v-a1632005]{display:flex;flex-direction:row;width:100%;background:#414a58;border-radius:4px;padding:8px;box-sizing:border-box;align-items:center}.terminal .cli .left .input .input-text[data-v-a1632005]{flex-grow:1;background:transparent;border:none;color:#fff;font-family:Courier New,Courier,monospace;font-size:14px;font-weight:400;line-height:17px;margin-top:3px}.terminal .cli .left .input .input-text[data-v-a1632005]:focus{outline:none}.terminal .cli .left .input .icon[data-v-a1632005]{align-self:flex-start}.terminal .cli .right[data-v-a1632005]{width:30px;display:flex;flex-direction:column;justify-content:space-between;align-items:center;margin-left:5px}.terminal .cli .right .icons[data-v-a1632005]{display:flex;justify-content:center;align-items:center;width:28px;height:28px;cursor:pointer}.terminal .cli .right .icons[data-v-a1632005]:hover{border:1px solid #ffffff;border-radius:4px;background:rgba(255,255,255,.2)}.smart-console[data-v-a1632005]{display:flex;position:fixed;flex-direction:column;bottom:0;left:0;width:100%;z-index:4}.smart-console .header[data-v-a1632005]{background:#414a58;display:flex;flex-direction:row;padding:8px 20px}.smart-console .header .header-button[data-v-a1632005]{cursor:pointer;display:flex;justify-content:center;align-items:center;background:rgba(255,255,255,.2);padding:4px 16px;gap:16px;height:30px;border:1px solid #ffffff;border-radius:4px;flex-shrink:0;color:#fff;font-weight:500;font-size:14px;line-height:20px;font-family:DM Sans,sans-serif}.smart-console .header .header-button[data-v-a1632005]:hover{background:#d4d8de;color:#272d35}.smart-console .header .header-button[data-v-a1632005]:active{background:#bdc3cc;color:#272d35;box-shadow:inset 1px 1px 2px #0000001a}.smart-console .header .header-button icon[data-v-a1632005]{width:16px;height:16px}.smart-console .header .left[data-v-a1632005]{display:flex;flex-direction:row;justify-content:start;align-items:center;gap:20px;width:50%;color:#fff}.smart-console .header .right[data-v-a1632005]{width:50%;display:flex;flex-direction:row;justify-content:end;align-items:center;gap:20px}.smart-console .header .right .changes-container[data-v-a1632005]{position:relative}.smart-console .header .right .toggle-button[data-v-a1632005]{cursor:pointer;display:flex;border-radius:3px}.smart-console .header .right .toggle-button[data-v-a1632005]:hover{background-color:#fff3}.smart-console .header .right .toggle-button .icon[data-v-a1632005]{transform:rotate(90deg)}.smart-console .header .right .toggle-button .icon[data-v-a1632005]:not(.open){transform:rotate(-90deg);transition:transform .4s ease}
