.table-settings[data-v-de65eac4]{width:960px;max-width:calc(100vw - 40px);padding:50px 0;align-self:center;display:flex;flex-direction:column;gap:10px}.table-settings .table-field[data-v-de65eac4]{display:flex}.table-settings .table-field .table-name[data-v-de65eac4]{border:1px solid #ccc;border-radius:5px;padding:5px 10px;font-size:16px;outline:none;transition:border-color .2s ease-in-out;flex-grow:1}.table-settings .table-field .table-name[data-v-de65eac4]:focus{border-color:#aaa}.table-settings .table-field .table-name[data-v-de65eac4]:hover{border-color:#8e8e8e}.table-settings .columns[data-v-de65eac4]{display:flex;flex-direction:column;gap:10px}.table-settings .columns .column[data-v-de65eac4]{display:flex;align-items:center;gap:5px}.table-settings .columns .column .column-name[data-v-de65eac4],.table-settings .columns .column .column-default[data-v-de65eac4]{border:1px solid #ccc;border-radius:5px;padding:5px 10px;font-size:16px;outline:none;transition:border-color .2s ease-in-out;flex-grow:1;flex-basis:0}.table-settings .columns .column .column-name[data-v-de65eac4]:focus,.table-settings .columns .column .column-default[data-v-de65eac4]:focus{border-color:#aaa}.table-settings .columns .column .column-name[data-v-de65eac4]:hover,.table-settings .columns .column .column-default[data-v-de65eac4]:hover{border-color:#8e8e8e}.table-settings .columns .column .column-type[data-v-de65eac4]{border:1px solid #ccc;border-radius:5px;padding:5px 10px;font-size:16px;outline:none;transition:border-color .2s ease-in-out}.table-settings .columns .column .column-type[data-v-de65eac4]:focus{border-color:#aaa}.table-settings .columns .column .column-type[data-v-de65eac4]:hover{border-color:#8e8e8e}.table-settings .button[data-v-de65eac4]{border:none;border-radius:5px;cursor:pointer;display:flex;align-items:center;justify-content:center;color:#8e8e8e;text-transform:uppercase}.table-settings .button.save.disabled[data-v-de65eac4]{opacity:.5;cursor:initial}.table-data{width:960px;max-width:calc(100vw - 40px);padding:50px 0;align-self:center}.table-data .add-row{padding:10px 20px;border:1px solid #ccc;border-radius:5px;font-size:16px;cursor:pointer;background-color:#fff}.table-data .add-row:hover{background-color:#eee}.table-data table{border-collapse:collapse;min-width:100%}.table-data table thead th{padding:.5em;border-bottom:1px solid #ddd}.table-data table thead .column-header{display:flex;justify-content:space-between}.table-data table thead .column-header .column-name{font-weight:700}.table-data table tbody tr td{padding:.5em;border-bottom:1px solid #ddd}.table-data table tbody tr:hover{background-color:#eee}.table-data table tbody tr .delete-row{cursor:pointer}.table-data .editing-row-container{top:50%;transform:translateY(-50%)}.table-data .editing-row-container .editing-row-content{display:flex;flex-direction:column;gap:10px}.table-data .editing-row-container .editing-row-content .editing-row-header{display:flex;justify-content:space-between;font-weight:700}.table-data .editing-row-container .editing-row-content .editing-row-header .close{cursor:pointer}.table-data .editing-row-container .editing-row-content .column{display:flex;flex-direction:column}.table-data .editing-row-container .editing-row-content .column input{border:1px solid #ccc;border-radius:5px;padding:5px 10px;font-size:16px}.table-connect .connect-example[data-v-0b54f9e9]{white-space:normal}
