import{d,r as b,G as N,b as s,c as n,A as B,v as r,H as y,z as A,y as x,q as u,F as k,J as S,K as R,L as E,E as $,e as i,I,B as v,t as C,w as D,N as L,O as T,a as F}from"./registerWidgets.d12d7cf9.js";import{d as P,s as z,w as V,a as W,b as H,c as J,e as M}from"./icons.a63cb90b.js";const U={class:"text"},j=d({__name:"Tooltip",props:{text:{type:String,required:!0},left:{type:Number},top:{type:Number},fixed:{type:Boolean,default:!1}},setup(e){const a=e,_=b(Date.now()),c=()=>{_.value=Date.now()},p=b(null),h=()=>{var t,g,w;const o=(t=p.value)==null?void 0:t.getBoundingClientRect();if(!o)return{};const{x:m,y:l}=o;return _.value,{position:"fixed",top:`${l+((g=a.top)!=null?g:0)}px`,left:`${m+((w=a.left)!=null?w:0)}px`}},f=N(()=>{var o;return a.fixed?h():{left:`${(o=a.left)!=null?o:-14}px`,...a.top?{top:`${a.top}px`}:{}}});return(o,m)=>(s(),n("div",{ref_key:"tooltipBox",ref:p,class:"tooltip-box",onMouseenter:c},[B(o.$slots,"default",{},void 0,!0),r("div",{class:"tooltip",style:A(x(f))},[r("span",U,y(e.text),1)],4)],544))}});const G=u(j,[["__scopeId","data-v-74636348"]]),K={class:"sidebar"},Q={class:"section-name"},X=["onClick"],Y={class:"item-name"},Z={key:0,class:"tag soon"},ee={key:1,class:"tag beta"},te={key:2,class:"tag cloud"},se=d({__name:"Sidebar",setup(e){var f;const a=R(),_=E(),c=b((f=_.name)!=null?f:"forms"),p=N(()=>[{name:"Runtime",items:[{name:"Forms",icon:P,path:"forms"},{name:"Jobs",icon:z,path:"jobs",cloud:!0},{name:"Hooks",icon:V,path:"hooks"},{name:"Dashes",icon:W,path:"dashes",beta:!0}]},{name:"Resources",items:[{name:"Tables",icon:H,path:"tables",beta:!0}]},{name:"Settings",items:[{name:"Settings",icon:J,path:"settings"}]}]),h=o=>{o.unavailable||(a.push(o.path),c.value=o.path)};return(o,m)=>(s(),n("div",K,[(s(!0),n(k,null,S(x(p),l=>(s(),n("div",{key:l.name,class:"section"},[r("span",Q,y(l.name),1),(s(!0),n(k,null,S(l.items,t=>(s(),n("div",{key:t.name,role:"button",class:$(["item",{active:c.value===t.path,disabled:t.unavailable||l.cloud}]),tabindex:"0",onClick:g=>h(t)},[i(I,{class:$(["icon",{disabled:t.unavailable,active:c.value===t.path}]),path:t.icon,width:"20",height:"20"},null,8,["class","path"]),r("span",Y,y(t.name),1),t.unavailable?(s(),n("span",Z,"SOON")):v("",!0),t.beta?(s(),n("span",ee,"BETA")):v("",!0),t.cloud?(s(),n("span",te,"CLOUD")):v("",!0),t.warning?(s(),C(G,{key:3,class:"warning",text:t.warning,fixed:!0,top:18,left:18},{default:D(()=>[i(I,{path:x(M),fill:"#D35249",width:"20",height:"20"},null,8,["path"])]),_:2},1032,["text"])):v("",!0)],10,X))),128))]))),128))]))}});const ae=u(se,[["__scopeId","data-v-873a191e"]]),oe="/assets/logo.0faadfa2.svg";const ne={},O=e=>(L("data-v-eafe8f3e"),e=e(),T(),e),ce={class:"logo"},re=O(()=>r("img",{class:"logo",src:oe,alt:"Abstra cloud logo"},null,-1)),_e=O(()=>r("span",null," Abstra ",-1)),le=[re,_e];function ie(e,a){return s(),n("div",ce,le)}const ue=u(ne,[["render",ie],["__scopeId","data-v-eafe8f3e"]]),pe=["href"],de=d({__name:"PrimaryLink",props:{url:{type:String,required:!0},alternative:{type:Boolean,required:!1}},setup(e){return(a,_)=>(s(),n("a",{target:"_blank",href:e.url,class:$([{alternative:e.alternative}])},[B(a.$slots,"default",{},void 0,!0)],10,pe))}});const he=u(de,[["__scopeId","data-v-eaebd10e"]]),q=e=>(L("data-v-308246f6"),e=e(),T(),e),fe=q(()=>r("span",{class:"long"}," DOCUMENTATION ",-1)),ve=q(()=>r("span",{class:"short"}," DOCS ",-1)),me=d({__name:"NavbarDocumentationLink",props:{page:{type:String,required:!1}},setup(e){var c;const _="https://docs.abstracloud.com/"+((c=e.page)!=null?c:"");return(p,h)=>(s(),C(he,{class:"button",url:_},{default:D(()=>[fe,ve]),_:1}))}});const ge=u(me,[["__scopeId","data-v-308246f6"]]),be={class:"workspace"},ye=d({__name:"Workspace",setup(e){return(a,_)=>{const c=F("router-view");return s(),n(k,null,[r("nav",null,[i(ue),i(ge)]),r("div",be,[i(ae,{class:"sidebar"}),i(c,{class:"view"})])],64)}}});const $e=u(ye,[["__scopeId","data-v-69a3c5a5"]]);export{$e as default};
//# sourceMappingURL=Workspace.efad2738.js.map
