import{x as n}from"./icons.5214a3f5.js";import{d as a,b as s,c,e as r,y as _,R as i,a as l,q as p}from"./registerWidgets.fff064a1.js";const u=a({__name:"BackButton",emits:["exitFullscreenPreview"],setup(m,{emit:t}){return(d,e)=>{const o=l("icon");return s(),c("button",{class:"back-btn",onClick:e[0]||(e[0]=B=>t("exitFullscreenPreview"))},[r(o,{class:"icon",path:_(n),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),i(" Editor ")])}}});const k=p(u,[["__scopeId","data-v-eaeb3a6e"]]);export{k as B};
//# sourceMappingURL=BackButton.9a7f01c9.js.map
